pub struct ClaudeMessage {
pub role: ClaudeMessageRole,
pub content: ClaudeMessageContent,
pub id: Option<String>,
}Expand description
Represents a message to be sent to the Claude API
Fields
role: ClaudeMessageRolecontent: ClaudeMessageContentid: Option<String>Trait Implementations
Sourceimpl Clone for ClaudeMessage
impl Clone for ClaudeMessage
Sourcefn clone(&self) -> ClaudeMessage
fn clone(&self) -> ClaudeMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaudeMessage
impl Debug for ClaudeMessage
Sourceimpl<'de> Deserialize<'de> for ClaudeMessage
impl<'de> Deserialize<'de> for ClaudeMessage
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ClaudeMessage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ClaudeMessage, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ClaudeMessage
impl PartialEq for ClaudeMessage
Sourcefn eq(&self, other: &ClaudeMessage) -> bool
fn eq(&self, other: &ClaudeMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ClaudeMessage
impl Serialize for ClaudeMessage
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ClaudeMessage