create_session_manager

Function create_session_manager 

pub async fn create_session_manager() -> Result<SessionManager>
Creates a SessionManager for use with the one-shot functions.

This is the recommended way to create a SessionManager for one-shot operations when you want to reuse it across multiple calls.