pub struct PartialSessionConfig {
pub schema: Option<String>,
pub workspace: Option<PartialWorkspaceConfig>,
pub tool_config: Option<PartialToolConfig>,
pub system_prompt: Option<String>,
pub metadata: Option<HashMap<String, String>>,
}Expand description
Partial session configuration that can be loaded from a TOML file. All fields are optional so users can specify only what they want to override.
Fields
schema: Option<String>workspace: Option<PartialWorkspaceConfig>tool_config: Option<PartialToolConfig>system_prompt: Option<String>metadata: Option<HashMap<String, String>>Trait Implementations
Sourceimpl Debug for PartialSessionConfig
impl Debug for PartialSessionConfig
Sourceimpl Default for PartialSessionConfig
impl Default for PartialSessionConfig
Sourcefn default() -> PartialSessionConfig
fn default() -> PartialSessionConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialSessionConfig
impl<'de> Deserialize<'de> for PartialSessionConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PartialSessionConfig
impl JsonSchema for PartialSessionConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PartialSessionConfig
impl RefUnwindSafe for PartialSessionConfig
impl Send for PartialSessionConfig
impl Sync for PartialSessionConfig
impl Unpin for PartialSessionConfig
impl UnsafeUnpin for PartialSessionConfig
impl UnwindSafe for PartialSessionConfig