pub struct PartialToolConfig {
pub backends: Option<Vec<BackendConfig>>,
pub visibility: Option<ToolVisibilityConfig>,
pub approval_policy: Option<ToolApprovalPolicyConfig>,
pub tools: Option<HashMap<String, PartialToolSpecificConfig>>,
}Fields
backends: Option<Vec<BackendConfig>>visibility: Option<ToolVisibilityConfig>approval_policy: Option<ToolApprovalPolicyConfig>tools: Option<HashMap<String, PartialToolSpecificConfig>>Trait Implementations
Sourceimpl Debug for PartialToolConfig
impl Debug for PartialToolConfig
Sourceimpl Default for PartialToolConfig
impl Default for PartialToolConfig
Sourcefn default() -> PartialToolConfig
fn default() -> PartialToolConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PartialToolConfig
impl<'de> Deserialize<'de> for PartialToolConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PartialToolConfig
impl JsonSchema for PartialToolConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PartialToolConfig
impl RefUnwindSafe for PartialToolConfig
impl Send for PartialToolConfig
impl Sync for PartialToolConfig
impl Unpin for PartialToolConfig
impl UnsafeUnpin for PartialToolConfig
impl UnwindSafe for PartialToolConfig